@@ -208,7 +208,7 @@ struct
   let copy {astart = CPointer src; alength} =
     begin
       let reftyp = Fat.reftype src in
-      let CPointer dst as r = allocate_n reftyp alength in
+      let CPointer dst as r = allocate_n reftyp ~count:alength in
       let () = Stubs.memcpy ~dst ~src ~size:(alength * sizeof reftyp) in
       from_ptr r alength
     end
